require 'yaml'

module PuntosPoint
  # Configuration variables wsdl_url, api user, api password
  class Config
    BASE_WSDL_URL = 'http://dev.puntospoint.com/api/cmr/events/wsdl'

    attr_accessor :config_filepath, :wsdl_url, :api_user, :api_password

    # Public: Loads the configuration file puntospoint.yml
    # If it's a rails application it will take the file from the config/ directory
    #
    # env - Environment.
    #
    # Returns a Config object.
    def initialize(env = nil)
      if env
        # For non-rails apps
        @config_filepath = File.join(File.dirname(__FILE__), "..", "..", "config", "puntospoint.yml")
        load(env)
      else
        @config_filepath = File.join(Rails.root, "config", "puntospoint.yml")
        load(Rails.env)
      end
    end

    private

    # Public: Initialize variables based on puntospoint.yml
    #
    # env - Environment.
    #
    # Returns nothing.
    def load(env)
      config = YAML.load_file(@config_filepath)[env]
      @wsdl_url = config['wsdl_url'] || BASE_WSDL_URL
      @api_user = config['api_user']
      @api_password = config['api_password']
    end

  end
end